import axios from 'axios';
import { Archive, Post } from './types';

const httpService = axios.create({
  headers: {
    'Cache-Control': 'no-cache',
    'Pragma': 'no-cache',
    'Expires': '0',
  }
});

httpService.interceptors.response.use(
  async response => response,
  async (error) => {
    console.error(`${error.request.status} (${error.request.statusText})`);
    return Promise.reject(error);
  },
);

export async function getArchive(baseUrl: string): Promise<Archive[]> {
  return await httpService.get<Archive[]>(`https://${baseUrl}/assets/posts/archive.json`).then((res: any) => {
    return res.data;
  }).catch(err => {
    alert(`Failed to load Archive! We've got a ${err.message}!\nAre you connected to the internet or is the location correct?`)
  });
}

export async function getPost(baseUrl: string, post: string): Promise<Post> {
  return await httpService.get<Post>(`https://${baseUrl}/assets/posts/${post}.json`).then((res: any) => {
    return res.data;
  }).catch(err => {
    alert(`Failed to load Post! We've got a ${err.message}!\nAre you connected to the internet?`)
  });
}